// java wrapper for vtkNewickTreeWriter object
//

package vtk;
import vtk.*;

public class vtkNewickTreeWriter extends vtkDataWriter
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native long GetInput_2();
  public vtkTree GetInput() {
    long temp = GetInput_2();

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native long GetInput_3(int id0);
  public vtkTree GetInput(int id0) {
    long temp = GetInput_3(id0);

    if (temp == 0) return null;
    return (vtkTree)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  private native String GetEdgeWeightArrayName_4();
  public String GetEdgeWeightArrayName()
    { return GetEdgeWeightArrayName_4(); }

  private native void SetEdgeWeightArrayName_5(String id0);
  public void SetEdgeWeightArrayName(String id0)
    { SetEdgeWeightArrayName_5(id0); }

  private native String GetNodeNameArrayName_6();
  public String GetNodeNameArrayName()
    { return GetNodeNameArrayName_6(); }

  private native void SetNodeNameArrayName_7(String id0);
  public void SetNodeNameArrayName(String id0)
    { SetNodeNameArrayName_7(id0); }

  public vtkNewickTreeWriter() { super(); }

  public vtkNewickTreeWriter(long id) { super(id); }
  public native long   VTKInit();

}
